@@ -470,7 +470,7 @@ int main (int argc, char *argv[]) {
   vbox1 = gtk_vbox_new (FALSE, 0);
   vbox2 = gtk_vbox_new (FALSE, 0);
   alignment1 = gtk_alignment_new (.5, .5, 0, 0);
-  label2 = gtk_label_new (_(""));
+  label2 = gtk_label_new ("");
   label3 = gtk_label_new (_("fps:"));
 
   load_rc();
@@ -573,8 +573,10 @@ int main (int argc, char *argv[]) {
     if (t) win_y = atoi(t+1);
     if (!want_quiet) 
       printf("window position: %ix%i \n", win_x, win_y);
-    if (win_x>=0 && win_y >=0 ) 
+    if (win_x>=0 && win_y >=0 ) {
+      gtk_window_set_gravity(GTK_WINDOW(window1), GDK_GRAVITY_STATIC);
       gtk_window_move(GTK_WINDOW(window1), win_x, win_y);
+    }
   }
 
   if (want_ontop) 
