@@ -24,6 +24,7 @@
 #endif
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <gtk/gtk.h>
 #include "gjack.h"
@@ -36,6 +37,7 @@ extern FrameRate *jffr;
 
 extern gint key_cfg[MAX_KEYBINDING];
 extern int max_mem;
+extern int no_resize;
 
 #ifdef HAVE_LASH
 # include <lash/lash.h>
@@ -271,6 +273,10 @@ void lash_process(void) {
 	#if 1
 		gtk_window_get_size (GTK_WINDOW(window1), &my_width, &my_height);
 		gtk_window_get_position (GTK_WINDOW(window1), &my_root_x, &my_root_y);
+		const gint prev_w = my_width;
+		const gint prev_h = my_height;
+		const gint prev_x = my_root_x;
+		const gint prev_y = my_root_y;
 	#endif
 	while ((ev = lash_get_event(lash_client)) != NULL) {
 		handle_event(ev);
@@ -282,10 +288,14 @@ void lash_process(void) {
 		flag=1;
 		// TODO do only if changed! -> flag
 	}
-	if (flag) {
-		gtk_window_resize(GTK_WINDOW(window1),my_width,my_height);
-		gtk_window_set_gravity(GTK_WINDOW(window1), GDK_GRAVITY_STATIC);
-		gtk_window_move(GTK_WINDOW(window1),my_root_x,my_root_y);
+	if (flag && no_resize) {
+		if (prev_w != my_width || prev_h != my_height) {
+			gtk_window_resize(GTK_WINDOW(window1),my_width,my_height);
+		}
+		if (prev_x != my_root_x || prev_y != my_root_y) {
+			gtk_window_set_gravity(GTK_WINDOW(window1), GDK_GRAVITY_STATIC);
+			gtk_window_move(GTK_WINDOW(window1),my_root_x,my_root_y);
+		}
 	}
 #endif
 }
